import { fireEvent } from '@testing-library/dom';
import { autocomplete } from '../autocomplete';
describe('autocomplete-js', function () {
  test('renders with default options', function () {
    var container = document.createElement('div');
    autocomplete({
      id: 'autocomplete',
      container: container,
      getSources: function getSources() {
        return [{
          getSuggestions: function getSuggestions() {
            return [{
              label: 'Item 1'
            }, {
              label: 'Item 2'
            }, {
              label: 'Item 3'
            }];
          }
        }];
      }
    });
    expect(container).toMatchInlineSnapshot("\n      <div>\n        <div\n          aria-expanded=\"false\"\n          aria-haspopup=\"listbox\"\n          aria-labelledby=\"autocomplete-label\"\n          aria-owns=\"undefined\"\n          class=\"aa-Autocomplete\"\n          role=\"combobox\"\n        >\n          <form\n            action=\"\"\n            class=\"aa-Form\"\n            novalidate=\"\"\n            role=\"search\"\n          >\n            <label\n              for=\"autocomplete-input\"\n              id=\"autocomplete-label\"\n            >\n              Search items\n            </label>\n            <div\n              class=\"aa-InputWrapper\"\n            >\n              <input\n                aria-activedescendant=\"undefined\"\n                aria-autocomplete=\"list\"\n                aria-controls=\"undefined\"\n                aria-labelledby=\"autocomplete-label\"\n                autocapitalize=\"off\"\n                autocomplete=\"off\"\n                autocorrect=\"off\"\n                class=\"aa-Input\"\n                id=\"autocomplete-input\"\n                maxlength=\"512\"\n                placeholder=\"\"\n                spellcheck=\"false\"\n                type=\"search\"\n              />\n              <button\n                type=\"reset\"\n              >\n                \uFF58\n              </button>\n            </div>\n          </form>\n          <div\n            class=\"aa-Dropdown\"\n            hidden=\"\"\n          />\n        </div>\n      </div>\n    ");
  });
  test('renders with autoFocus', function () {
    var container = document.createElement('div');
    autocomplete({
      id: 'autocomplete',
      container: container,
      autoFocus: true,
      getSources: function getSources() {
        return [{
          getSuggestions: function getSuggestions() {
            return [{
              label: 'Item 1'
            }, {
              label: 'Item 2'
            }, {
              label: 'Item 3'
            }];
          }
        }];
      }
    });
    var input = container.querySelector('.aa-Input');
    expect(input).toHaveAttribute('autofocus', 'true');
  });
  test('renders with placeholder', function () {
    var container = document.createElement('div');
    autocomplete({
      id: 'autocomplete',
      container: container,
      placeholder: 'Placeholder',
      getSources: function getSources() {
        return [{
          getSuggestions: function getSuggestions() {
            return [{
              label: 'Item 1'
            }, {
              label: 'Item 2'
            }, {
              label: 'Item 3'
            }];
          },
          templates: {
            item: function item(_ref) {
              var item = _ref.item;
              return item.label;
            }
          }
        }];
      }
    });
    var input = container.querySelector('.aa-Input');
    expect(input).toHaveAttribute('placeholder', 'Placeholder');
  });
  test('renders with initial query', function () {
    var container = document.createElement('div');
    autocomplete({
      id: 'autocomplete',
      container: container,
      initialState: {
        query: 'Query'
      },
      getSources: function getSources() {
        return [{
          getSuggestions: function getSuggestions() {
            return [{
              label: 'Item 1'
            }, {
              label: 'Item 2'
            }, {
              label: 'Item 3'
            }];
          },
          templates: {
            item: function item(_ref2) {
              var item = _ref2.item;
              return item.label;
            }
          }
        }];
      }
    });
    var input = container.querySelector('.aa-Input');
    expect(input).toHaveValue('Query');
  });
  test('renders on input', function () {
    var container = document.createElement('div');
    autocomplete({
      id: 'autocomplete',
      container: container,
      getSources: function getSources() {
        return [{
          getSuggestions: function getSuggestions() {
            return [{
              label: 'Item 1'
            }, {
              label: 'Item 2'
            }, {
              label: 'Item 3'
            }];
          },
          templates: {
            item: function item(_ref3) {
              var item = _ref3.item;
              return item.label;
            }
          }
        }];
      }
    });
    var input = container.querySelector('.aa-Input');
    fireEvent.input(input, {
      target: {
        value: 'a'
      }
    });
    input.focus();
    expect(input).toHaveValue('a');
  });
});